@@ -10,7 +10,6 @@ BEGIN {
         $Data::Dumper::Deparse = 1;
 }
 
-
 sub import {
 	my $package = caller();
 	no strict 'refs';
@@ -79,53 +78,34 @@ sub _stack {
 	return %{$msg};
 }
 
-
-
-
 =head1 NAME
 
-Glitch - The great new Glitch!
+Glitch - Exception Handling.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
+	use Glitch;
 
-Perhaps a little code snippet.
+	do { ... } or glitch('one', message => 'Create a new glitch error message');
 
-    use Glitch;
+	...
 
-    my $foo = Glitch->new();
-    ...
+	do { ... } or glitch('one'); 
 
 =head1 EXPORT
 
-A list of functions that can be exported.  You can delete this section
-if you don't export anything, such as for a purely object-oriented module.
-
-=head1 SUBROUTINES/METHODS
-
-=head2 function1
+=head2 glitch
 
 =cut
 
-sub function1 {
-}
-
-=head2 function2
-
-=cut
-
-sub function2 {
-}
-
 =head1 AUTHOR
 
 LNATION, C<< <email at lnation.org> >>
@@ -136,16 +116,12 @@ Please report any bugs or feature requests to C<bug-glitch at rt.cpan.org>, or t
 the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=Glitch>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Glitch
 
-
 You can also look for information at:
 
 =over 4
@@ -164,10 +140,8 @@ L<https://metacpan.org/release/Glitch>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 LICENSE AND COPYRIGHT
 
 This software is Copyright (c) 2022 by LNATION.
@@ -176,7 +150,6 @@ This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
-
 =cut
 
 1; # End of Glitch
